Class: DeviceAPI::IOS::IDeviceScreenshot
- Inherits:
-
Execution
- Object
- Execution
- DeviceAPI::IOS::IDeviceScreenshot
- Defined in:
- lib/device_api/ios/idevicescreenshot.rb
Overview
Namespace for all methods encapsulating idevicescreenshot calls
Class Method Summary collapse
-
.capture(args) ⇒ Object
Take a screenshot of the device based on the provided UUID.
Class Method Details
.capture(args) ⇒ Object
Take a screenshot of the device based on the provided UUID
10 11 12 13 |
# File 'lib/device_api/ios/idevicescreenshot.rb', line 10 def self.capture(args) result = execute("idevicescreenshot #{args[:filename]} -u #{args[:device_id]}") raise IDeviceScreenshotError.new(result.stderr) if result.exit != 0 end |